import Carousel from "react-multi-carousel";
import "react-multi-carousel/lib/styles.css";
import Link from "next/link";
import Image from 'next/image';
import styles from '../Component/Componentstyle/Categoryslider.module.css';
import { ArrowBackIos, ArrowForwardIos } from '@material-ui/icons';

const CustomRight = ({ onClick }) => (
  <button className="arrow_rightcmn" onClick={onClick} >
    <ArrowBackIos className="arrowiconcmn" />
  </button>
);
const CustomLeft = ({ onClick }) => (
  <button className="arrow_leftcmn" onClick={onClick} >
    <ArrowForwardIos className="arrowiconcmn" />
  </button>
);

const responsive = {
  superLargeDesktop: {
    breakpoint: { max: 4000, min: 3000 },
    items: 5
  },
  desktop: {
    breakpoint: { max: 3000, min: 1024 },
    items: 4
  },
  tablet: {
    breakpoint: { max: 1024, min: 464 },
    items: 2
  },
  mobile: {
    breakpoint: { max: 464, min: 0 },
    items: 1
  }
};
const convertImage = (w, h) => `
<svg width="${w}" height="${h}" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
  <defs>
    <linearGradient id="g">
      <stop stop-color="#eae9e9" offset="20%" />
      <stop stop-color="#bbb" offset="50%" />
      <stop stop-color="#eae9e9" offset="70%" />
    </linearGradient>
  </defs>
  <rect width="${w}" height="${h}" fill="#eae9e9" />
  <rect id="r" width="${w}" height="${h}" fill="url(#g)" />
  <animate xlink:href="#r" attributeName="x" from="-${w}" to="${w}" dur="1s" repeatCount="indefinite"  />
</svg>`;

const toBase64 = (str) =>
  typeof window === 'undefined'
    ? Buffer.from(str).toString('base64')
    : window.btoa(str);

export default function CategorySlider() {
  return (
<div className={`${styles.cat_slider} cat-slider`}>
      <Carousel
        additionalTransfrom={0}
        autoPlaySpeed={3000}
        centerMode={false}
        className={styles.react_multi_carousel}
        containerClass="container-with-dots"
        dotListClass=""
        draggable
        focusOnSelect={false}
        infinite
        itemClass=""
        keyBoardControl
        minimumTouchDrag={80}
        renderButtonGroupOutside={false}
        renderDotsOutside={false}
        customRightArrow={<CustomRight />}
        customLeftArrow={<CustomLeft />}
        responsive={{
          desktop: {
            breakpoint: {
              max: 3000,
              min: 1024
            },
            items: 4,
            partialVisibilityGutter: 40
          },
          mobile: {
            breakpoint: {
              max: 480,
              min: 320
            },
            items: 2,
            partialVisibilityGutter: 30
          },
          ipad: {
            breakpoint: {
              max: 767,
              min: 481
            },
            items: 3,
            partialVisibilityGutter: 30
          },
          tablet: {
            breakpoint: {
              max: 1024,
              min: 768
            },
            items: 4,
            partialVisibilityGutter: 30
          }
        }}
        showDots={false}
        sliderClass=""
        slidesToSlide={1}
        swipeable
      >

        <div className={`${styles.categoryslide} categoryslide`}>
          <Link href='/designer-cakes'><a><Image src="/Egift/cakes/designer cakes.webp" alt='Send designer cakes' width="342" height="399"  title='Designer Cakes' type="image/jpeg" placeholder="blur" blurDataURL={`data:image/svg+xml;base64,${toBase64(convertImage(342, 399))}`} 
            style={{
              display: 'block',
              height: '100%',
              margin: 'auto',
              width: '100%'
            }}
          /></a></Link>
            <Link href='/designer-cakes'><a className={styles.cat_slide_text}>Designer Cakes</a></Link>
        </div>

        <div className={`${styles.categoryslide} categoryslide`}>
          <Link href='/chocolate-cakes'><a><Image src="/Egift/cakes/chocolate cakes.webp" alt='Send chocolate cakes' width="342" height="399"  title='Chocolate Cakes' type="image/jpeg" placeholder="blur" blurDataURL={`data:image/svg+xml;base64,${toBase64(convertImage(342, 399))}`}
            style={{
              display: 'block',
              height: '100%',
              margin: 'auto',
              width: '100%'
            }}
          /></a></Link>  
          <Link href='/chocolate-cakes'><a className={styles.cat_slide_text}>Chocolate Cakes</a></Link> 
        </div>

        <div className={`${styles.categoryslide} categoryslide`}>
         <Link href='/black-forest-cakes'><a><Image src="/Egift/cakes/black forest cake.webp" alt='Send black forest cakes' width="342" height="399"  title='Black Forest Cakes' type="image/jpeg" placeholder="blur" blurDataURL={`data:image/svg+xml;base64,${toBase64(convertImage(342, 399))}`}
            style={{
              display: 'block',
              height: '100%',
              margin: 'auto',
              width: '100%'
            }}
          /></a></Link>
         <Link href='/black-forest-cakes'><a className={styles.cat_slide_text}>Black Forest Cakes</a></Link>  
        </div>

        <div className={`${styles.categoryslide} categoryslide`}>
          <Link href='/butterscotch-cakes'><a><Image src="/Egift/cakes/butterscotch cakes.webp" alt='Send butterscotch cakes' width="342" height="399"  title='Butterscotch Cakes' type="image/jpeg" placeholder="blur" blurDataURL={`data:image/svg+xml;base64,${toBase64(convertImage(342, 399))}`}
            style={{
              display: 'block',
              height: '100%',
              margin: 'auto',
              width: '100%'
            }}
          /></a></Link>  
          <Link href='/butterscotch-cakes'><a className={styles.cat_slide_text}>Butterscotch Cakes</a></Link>  
        </div>

        
        
      </Carousel>


    </div>
  )
}
