import React, { useState } from 'react';
import { getCsrfToken } from "next-auth/react"
import { getProviders, signIn } from "next-auth/react"
import Footer from '../../components/Footer/Footer';
import Navbar from "../../components/Navbar/Navbar";
import Grid from '@material-ui/core/Grid';
import { useRouter } from "next/router";
import Head from 'next/head';
import { AiFillGoogleCircle } from "react-icons/ai";
import { BsFacebook } from "react-icons/bs";
import config from '../../config/config'
import LockOpenIcon from '@material-ui/icons/LockOpen';


export default function Resetpassword({ csrfToken, providers, currentCurrency, AllCurrencyData, GeoData }) {
	const { error } = useRouter().query;
	const [resetToken, setresetToken] = useState(decodeURI(useRouter().query.token))
	const [resetEmail, setresetEmail] = useState(decodeURI(useRouter().query.email))
	const [newPass, setnewPass] = useState('')
	const [newconfirmPass, setnewconfirmPass] = useState('')

	const [newPassErr, setnewPassErr] = useState(false)
	const [newconfirmPassErr, setnewconfirmPassErr] = useState(false)
	const [passconfirmpassErr, setpassconfirmpassErr] = useState(false)
	const [linkexpiredErr, setlinkexpiredErr] = useState(false)



	const [successMsg, setsuccessMsg] = useState(false)

	function getPassword(e) {
		setnewPassErr(false)
		setsuccessMsg(false)
		setnewconfirmPassErr(false)
		setpassconfirmpassErr(false)
		var value = e.target.value
		setnewPass(value)
	}


	function getConfirmPassword(e) {
		setnewPassErr(false)
		setnewconfirmPassErr(false)
		setpassconfirmpassErr(false)
		setsuccessMsg(false)
		var value = e.target.value
		setnewconfirmPass(value)
	}


	async function resetpasswordApi(e) {
		e.preventDefault()
		setsuccessMsg(false)
		if (!newPass) {
			setnewPassErr(true)
		} else if (!newconfirmPass) {
			setnewconfirmPassErr(true)
		} else if (newPass !== newconfirmPass) {
			setpassconfirmpassErr(true)
		} else {
			const registerResp = await fetch(`${config.apiUrl}auth/resetpassword`, {
				method: "POST",
				body: JSON.stringify({ email: resetEmail, resetToken: resetToken, newPass: newPass }),
				headers: {
					"Content-Type": "application/json",
				},
			}).then(function (response) {
				if (response.status == 200) {
					setsuccessMsg(true);
					setnewPassErr('');
					setnewconfirmPassErr('');

					setresetEmail('');
					setnewPass('');
					setnewconfirmPass('');

				} if (response.status == 403) {
					setlinkexpiredErr(true)
					setnewPassErr('')
					setnewconfirmPassErr('')
				} else {

				}
			});
		}
		setTimeout(function () {
			setsuccessMsg('')
			setlinkexpiredErr('')
			setpassconfirmpassErr('')
		}, 3500);
	}

	return (
		<>
			<div className='maincointainer' key='div1'>
				<Head>
					<title>Reset Password - 1800rakhis</title>
				</Head>
				<div className='somehideflag'>
					<Navbar countryId={''} currentCurrency={currentCurrency} AllCurrencyData={AllCurrencyData} GeoData={GeoData} />
				</div>
				<Grid container className='forget' >
					{/* <Grid item md={4}>
			</Grid> */}
					<Grid item md={12} sm={12} xs={12}>

						<form method="post" >

							<div className="forget_form_inner">
								<div className="err-div resetpaswwrorderr">
									{(newPassErr) ?
										<p>Password is required</p>
										:
										(newconfirmPassErr) ?
											<p>Confirm Password is required</p>
											:
											(passconfirmpassErr) ?
												<p>Password and confirm Password do not match</p>
												:
												(linkexpiredErr) ?
													<p>Reset password link expired</p>
													:
													''
									}
								</div>
								<div className="succ-div resetpaswwrorderr">
									{(successMsg) ?
										<p>Password updated Succesfully</p>
										:
										''
									}
								</div>
								<h2>Reset Password?</h2>
								<div className='reset_in_sec' >
									<div className="reset-input-wrp">
										<br />

										<input type="password" className="inputText" required onChange={(e) => getPassword(e)} value={newPass} />
										<LockOpenIcon width='18' className='reset_form_icon' />
										<span className="floating-label">Enter Password</span>
									</div>

									<div className="reset-input-wrp  input_confirm">
										<br />

										<input type="password" className="inputText" required onChange={(e) => getConfirmPassword(e)} value={newconfirmPass} />
										<LockOpenIcon width='18' className='reset_form_icon' />
										<span className="floating-label">Enter Confirm Password</span>
									</div>

								</div>


								<button type="submit" className='forget_submit  procartbtn' onClick={(e) => resetpasswordApi(e)}>Submit</button>

							</div>
						</form>
					</Grid>

				</Grid>
				<Footer footerdata={''} />
			</div>
		</>
	)


}


export async function getServerSideProps(context) {
	if (typeof (context.req.cookies.CurrencyData) !== 'undefined') {
		var currentCurrency = JSON.parse(context.req.cookies.CurrencyData)
		var AllCountryData = JSON.parse(context.req.cookies.AllCountryData)
		var GeoData = JSON.parse(context.req.cookies.GeoData)
	} else {
		const forwarded = context.req.headers["x-forwarded-for"]
		const ip = forwarded ? forwarded.split(/, /)[0] : context.req.connection.remoteAddress
		const res = await fetch(`${config.apiUrl}setcurrency/?ip=${ip}`);
		var geoapiresponse = await res.json();

		var currentCurrency = geoapiresponse.current_currency
		var AllCountryData = geoapiresponse.all_currency
		var GeoData = geoapiresponse.GeoData
	}

	const providers = await getProviders()
	return {
		props: {
			csrfToken: await getCsrfToken(context),
			providers: providers, currentCurrency: currentCurrency, AllCurrencyData: AllCountryData, GeoData: GeoData
		},
	}
}